==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebNavDrawerItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerItemDescription } from "./WebNavDrawerItemDescription";
/**
 * @hidden
 */
export let WebNavDrawerItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerItemDescriptionMetadata.a == null) {
                WebNavDrawerItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerItemDescriptionMetadata.c(WebNavDrawerItemDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerItemDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebNavDrawerItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawerItem");
            a.item("__tagNameWC", "String:igc-nav-drawer-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Disabled", "Boolean");
            a.item("Active", "Boolean");
        }
        static d(a) {
            WebNavDrawerItemDescriptionMetadata.b(a);
            a.ad("WebNavDrawerItem", () => new WebNavDrawerItemDescription());
            a.ac("WebNavDrawerItem", WebNavDrawerItemDescriptionMetadata.a);
        }
    }
    WebNavDrawerItemDescriptionMetadata.$t = markType(WebNavDrawerItemDescriptionMetadata, 'WebNavDrawerItemDescriptionMetadata');
    WebNavDrawerItemDescriptionMetadata.a = null;
    return WebNavDrawerItemDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebNavDrawerItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerItemDescription } from "./WebNavDrawerItemDescription";
/**
 * @hidden
 */
export let WebNavDrawerItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavDrawerItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavDrawerItemDescriptionMetadata.a == null) {
                WebNavDrawerItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavDrawerItemDescriptionMetadata.c(WebNavDrawerItemDescriptionMetadata.a);
            }
            if (a.k(WebNavDrawerItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebNavDrawerItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NavDrawerItem");
            a.item("__tagNameWC", "String:igc-nav-drawer-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Disabled", "Boolean");
            a.item("Active", "Boolean");
        }
        static d(a) {
            WebNavDrawerItemDescriptionMetadata.b(a);
            a.ae("WebNavDrawerItem", () => new WebNavDrawerItemDescription());
            a.ad("WebNavDrawerItem", WebNavDrawerItemDescriptionMetadata.a);
        }
    }
    WebNavDrawerItemDescriptionMetadata.$t = markType(WebNavDrawerItemDescriptionMetadata, 'WebNavDrawerItemDescriptionMetadata');
    WebNavDrawerItemDescriptionMetadata.a = null;
    return WebNavDrawerItemDescriptionMetadata;
})();
